Django simple account
================================

.. image:: https://github.com/kostya-ten/django_simple_account/workflows/Workflows/badge.svg
     :target: https://github.com/kostya-ten/django_simple_account/actions/
     :alt: GihHub Action

.. image:: https://requires.io/github/kostya-ten/django_simple_account/requirements.svg?branch=master
     :target: https://requires.io/github/kostya-ten/django_simple_account/requirements/?branch=master
     :alt: Requirements Status

.. image:: https://badge.fury.io/py/django-simple-account.svg
     :target: https://badge.fury.io/py/django-simple-account
     :alt: pypi


Requirements
""""""""""""""""""
* Python 3.6+
* A supported version of Django (currently 3.x)

Getting It
""""""""""""""""""
You can get Django tree materialized by using pip::

    $ pip install django-simple-account

If you want to install it from source, grab the git repository from GitHub and run setup.py::

    $ git clone git://github.com/kostya-ten/django_simple_account.git
    $ cd django_simple_account
    $ python setup.py install
